#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

source ${SCRIPT_DIR}/utilis/colors.sh

DEFAULT_WP_VERSION=4.9.15
DEFAULT_WP_LANGUAGE=US
DEFAULT_WP_LOCATION=www
WORDPRESS_PATHS=(
  index.php
  licens*
  readme.html
  wp-activate.php
  wp-admin/
  wp-blog-header.php
  wp-comments-post.php
  wp-content/index.php
  wp-content/languages/
  wp-content/plugins/index.php
  wp-content/themes/index.php
  wp-cron.php
  wp-includes/
  wp-links-opml.php
  wp-load.php
  wp-login.php
  wp-mail.php
  wp-settings.php
  wp-signup.php
  wp-trackback.php
  xmlrpc.php
)

WORDPRESS_CLEANUP_PATHS=(
 wp-content/themes/twenty*
 wp-content/languages/themes/twenty*
 wp-content/plugins/hello.php
 wp-content/plugins/akismet
 wp-content/languages/plugins/akismet*
 wp-config-sample.php
)

function removeWordpress() {

  local __LOCATION=${1:-www}

  local PATHS=("${WORDPRESS_PATHS[@]/#/${__LOCATION}/}")

  rm -rf ${PATHS[@]}
}

function getStarterKitVersions () {
  local __JSON=https://composer.infomaker.io/versions.json
  local __NAME=infomaker/everyware-starter-kit

  echo $(node -e "const r=require('request'),n='${__NAME}';r('${__JSON}',(e,res,b)=>{console.log(!e && res.statusCode === 200 ? JSON.parse(b).filter(a=>a.name==n)[0].versions.join(' '):'');})")
}

function downloadWordpress() {
  local __WORDPRESS_ZIP=${1}
  local __LOCATION=${2:-${DEFAULT_WP_LOCATION}}

  TEMP_DIR="./tmp/wordpress"

  echo "${GREEN}${BOLD}> Downloading WordPress from ${__WORDPRESS_ZIP}${RESET}"

  # Download Wordpress
  curl -L -o "${TEMP_DIR}.tar.gz" --create-dirs ${__WORDPRESS_ZIP}

  echo "${GREEN}${BOLD}> Unpacking${RESET}"

  # Extract file file
  tar -zxf "${TEMP_DIR}.tar.gz" -C ./tmp/

  # Add or replace files
  rsync -a "${TEMP_DIR}/" ${__LOCATION}

  # Remove tempfiles
  rm -rf ./tmp*

  echo "${GREEN}${BOLD}> Cleaning up${RESET}"

  # Prefix cleanup paths with location
  CLEANUP_PATHS=("${WORDPRESS_CLEANUP_PATHS[@]/#/${__LOCATION}/}")
  rm -rf ${CLEANUP_PATHS[@]}
}

function installWordpress() {
  local __VERSION=${1:-${DEFAULT_WP_VERSION}}
  local __LANGUAGE=${2:-${DEFAULT_WP_LANGUAGE}}
  local __LOCATION=${3:-${DEFAULT_WP_LOCATION}}

  wordpressUrl=$(createWordpressUrl ${__VERSION} "${__LANGUAGE}")

  downloadWordpress ${wordpressUrl} ${__LOCATION}
}

function createWordpressUrl() {
  local __VERSION=${1:-${DEFAULT_WP_VERSION}}
  local __LANGUAGE=${2:-${DEFAULT_WP_LANGUAGE}}

  local FILENAME="wordpress-${__VERSION}"
  local DOMAIN="wordpress.org"

  case ${__LANGUAGE} in
  "DK")
    FILENAME="${FILENAME}-da_DK"
    DOMAIN="da.${DOMAIN}"
    ;;
  "FI")
    FILENAME="${FILENAME}-fi"
    DOMAIN="fi.${DOMAIN}"
    ;;
  "NB")
    FILENAME="${FILENAME}-nb_NO"
    DOMAIN="nb.${DOMAIN}"
    ;;
  "NN")
    FILENAME="${FILENAME}-nn_NO"
    DOMAIN="nn.${DOMAIN}"
    ;;
  "SE")
    FILENAME="${FILENAME}-sv_SE"
    DOMAIN="sv.${DOMAIN}"
    ;;
  esac

  echo "https://${DOMAIN}/${FILENAME}.tar.gz"
}
