#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

source ${SCRIPT_DIR}/utilis/colors.sh

cwd=$(pwd)

WORDPRESS_VERSION="4.9.15"
WORDPRESS_LANGUGE=US

# Array of dependencies to the project
dependencies=("docker" "composer")
RUN_GULP=false

# Check for npm dependency.
if [ -f "${cwd}/package.json" ]; then
  dependencies+=('node')
  dependencies+=('npm')
fi

# Check for gulp dependency.
if [ -f "${cwd}/gulpfile.php" ]; then
  dependencies+=('gulp')
  RUN_GULP=true
fi

for i in "${dependencies[@]}"; do
  if command -v $i >/dev/null 2>&1; then
    echo "${GREEN}> $i version: $($i --version)${RESET}"
  else
    echo "${RED}> $i not found. Install it and rerun this script.${RESET}"
    exit 1
  fi
done

# Create a .env.example file
[[ ! -f .project-env ]] || [[ -f .env.example ]] || mv .project-env .env.example

# Create a .env file
[[ ! -f .env.example ]] || [[ -f .env ]] || cp .env.example .env

# Create project .gitignore
[[ ! -f .project-gitignore ]] || [[ -f .gitignore ]] || mv .project-gitignore .gitignore

# Install WordPress
${SCRIPT_DIR}/wordpress-install.sh -l ${WORDPRESS_LANGUGE} --version ${WORDPRESS_VERSION}

make pull
make luarocks
composer install

# Run gulp build
if [ RUN_GULP ]; then
  read -p "Do you wish to run gulp (y/n)? " -n 1 -r
  echo ""
  if [[ $REPLY =~ ^[Yy]$ ]]; then
     npm install && gulp
  fi
fi
echo ""
echo "${RED}> Don't forget to update hosts. Read more about in ${BOLD}README.md${RESET}"
